==> 0.0.2.tar.gz: android/src/main/java/com/yifan/yf_ads/admanager/DrawFeedVideoAdManager.java <==
package com.yifan.yf_ads.admanager;

import android.app.Activity;
import android.view.ViewGroup;
import android.widget.FrameLayout;

import com.yfanads.android.core.draw.YFAdDrawAds;
import com.yfanads.android.core.draw.YFDrawListener;
import com.yfanads.android.model.YFAdError;
import com.yifan.yf_ads.bean.DrawFeedVideoBean;
import com.yifan.yf_ads.utils.Constants;

import org.json.JSONException;
import org.json.JSONObject;

import io.flutter.plugin.common.EventChannel;

/**
 * 一句话描述该类功能.
 *
 * @author JamesQian
 * @version 1.0
 * @copyright 亿帆
 * @date 2024/1/26 13:44
 **/
public class DrawFeedVideoAdManager extends CommonAdManager {

    private YFAdDrawAds easyAdDraw;

    public DrawFeedVideoAdManager(Activity activity, String adType) {
        super(activity, adType);
    }


    public void requestNativeDrawFeedVideoAD(int viewId, final DrawFeedVideoBean nativeDrawFeedVideoBean, final EventChannel.EventSink eventSink) {


        release();
        easyAdDraw = new YFAdDrawAds(activity, new YFDrawListener() {

            @Override
            public void onAdSuccess() {
                callAdSuccess();

                try {
                    JSONObject jsonObject = new JSONObject();
                    jsonObject.put(Constants.KEY_METHOD, "onDrawFeedExpressAdLoaded");
                    jsonObject.put(Constants.KEY_VIEW_ID, viewId);
                    callBack(jsonObject, eventSink);
                } catch (JSONException e) {
                    e.printStackTrace();
                }

            }

            @Override
            public void onAdExposure() {
                try {
                    JSONObject jsonObject = new JSONObject();
                    jsonObject.put(Constants.KEY_METHOD, "onAdShow");
                    jsonObject.put(Constants.KEY_VIEW_ID, viewId);
                    callBack(jsonObject, eventSink);
                } catch (JSONException e) {
                    e.printStackTrace();
                }

            }

            @Override
            public void onAdClicked() {
                try {
                    JSONObject jsonObject = new JSONObject();
                    jsonObject.put(Constants.KEY_METHOD, "onAdClicked");
                    jsonObject.put(Constants.KEY_VIEW_ID, viewId);
                    callBack(jsonObject, eventSink);
                } catch (JSONException e) {
                    e.printStackTrace();
                }
            }

            @Override
            public void onAdClosed() {
                callAdClose();
            }

            @Override
            public void onAdFailed(YFAdError fcAdError) {
                callAdFail(fcAdError.msg);
                try {
                    JSONObject jsonObject = new JSONObject();
                    jsonObject.put(Constants.KEY_METHOD, "onFailed");
                    jsonObject.put(Constants.KEY_ERROR, fcAdError.msg);
                    jsonObject.put(Constants.KEY_VIEW_ID, viewId);
                    callBack(jsonObject, eventSink);
                } catch (JSONException e) {
                    e.printStackTrace();
                }
            }


        });
        //必须：设置策略信息
        easyAdDraw.loadOnly(nativeDrawFeedVideoBean.getPositionId());
    }

    public void showAds(Activity activity, ViewGroup viewGroup) {
        if (easyAdDraw != null && activity != null) {
            easyAdDraw.showAds(activity, viewGroup);
        }
    }

    private void release() {
        if (easyAdDraw != null) {
            easyAdDraw.destroy();
        }
    }

    @Override
    public void destroy() {
        super.destroy();
        if (easyAdDraw != null) {
            easyAdDraw.destroy();
        }
    }
}

==> 0.0.9.tar.gz: android/src/main/java/com/yifan/yf_ads/admanager/DrawFeedVideoAdManager.java <==
package com.yifan.yf_ads.admanager;

import android.app.Activity;
import android.view.ViewGroup;
import android.widget.FrameLayout;

import com.yfanads.android.core.draw.YFAdDrawAds;
import com.yfanads.android.core.draw.YFDrawListener;
import com.yfanads.android.model.YFAdError;
import com.yifan.yf_ads.bean.DrawFeedVideoBean;
import com.yifan.yf_ads.utils.Constants;

import org.json.JSONException;
import org.json.JSONObject;

import io.flutter.plugin.common.EventChannel;

/**
 * 一句话描述该类功能.
 *
 * @author JamesQian
 * @version 1.0
 * @copyright 亿帆
 * @date 2024/1/26 13:44
 **/
public class DrawFeedVideoAdManager extends CommonAdManager {

    private YFAdDrawAds easyAdDraw;

    public DrawFeedVideoAdManager(Activity activity, String adType) {
        super(activity, adType);
    }


    public void requestNativeDrawFeedVideoAD(String viewId, final DrawFeedVideoBean nativeDrawFeedVideoBean, final EventChannel.EventSink eventSink) {


        release();
        easyAdDraw = new YFAdDrawAds(activity, new YFDrawListener() {

            @Override
            public void onAdSuccess() {
                callAdSuccess();

                try {
                    JSONObject jsonObject = new JSONObject();
                    jsonObject.put(Constants.KEY_METHOD, "onDrawFeedExpressAdLoaded");
                    jsonObject.put(Constants.KEY_VIEW_ID, viewId);
                    callBack(jsonObject, eventSink);
                } catch (JSONException e) {
                    e.printStackTrace();
                }

            }

            @Override
            public void onAdExposure() {
                try {
                    JSONObject jsonObject = new JSONObject();
                    jsonObject.put(Constants.KEY_METHOD, "onAdShow");
                    jsonObject.put(Constants.KEY_VIEW_ID, viewId);
                    callBack(jsonObject, eventSink);
                } catch (JSONException e) {
                    e.printStackTrace();
                }

            }

            @Override
            public void onAdClicked() {
                try {
                    JSONObject jsonObject = new JSONObject();
                    jsonObject.put(Constants.KEY_METHOD, "onAdClicked");
                    jsonObject.put(Constants.KEY_VIEW_ID, viewId);
                    callBack(jsonObject, eventSink);
                } catch (JSONException e) {
                    e.printStackTrace();
                }
            }

            @Override
            public void onAdClosed() {
                callAdClose();
            }

            @Override
            public void onAdFailed(YFAdError fcAdError) {
                callAdFail(fcAdError.msg);
                try {
                    JSONObject jsonObject = new JSONObject();
                    jsonObject.put(Constants.KEY_METHOD, "onFailed");
                    jsonObject.put(Constants.KEY_ERROR, fcAdError.msg);
                    jsonObject.put(Constants.KEY_VIEW_ID, viewId);
                    callBack(jsonObject, eventSink);
                } catch (JSONException e) {
                    e.printStackTrace();
                }
            }


        });
        //必须：设置策略信息
        easyAdDraw.loadOnly(nativeDrawFeedVideoBean.getPositionId());
    }

    public void showAds(Activity activity, ViewGroup viewGroup) {
        if (easyAdDraw != null && activity != null) {
            easyAdDraw.showAds(activity, viewGroup);
        }
    }

    private void release() {
        if (easyAdDraw != null) {
            easyAdDraw.destroy();
        }
    }

    @Override
    public void destroy() {
        super.destroy();
        if (easyAdDraw != null) {
            easyAdDraw.destroy();
        }
    }
}
